==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/OnBalanceVolumeIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { OnBalanceVolumeIndicatorStrategy } from "./OnBalanceVolumeIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var OnBalanceVolumeIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(OnBalanceVolumeIndicator, _super);
    function OnBalanceVolumeIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OnBalanceVolumeIndicator.prototype.get_yy = function () {
        return new OnBalanceVolumeIndicatorStrategy();
    };
    Object.defineProperty(OnBalanceVolumeIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    OnBalanceVolumeIndicator.prototype.get_zb = function () {
        return OnBalanceVolumeIndicator.$;
    };
    Object.defineProperty(OnBalanceVolumeIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    OnBalanceVolumeIndicator.$t = markType(OnBalanceVolumeIndicator, 'OnBalanceVolumeIndicator', StrategyBasedIndicator.$);
    return OnBalanceVolumeIndicator;
}(StrategyBasedIndicator));
export { OnBalanceVolumeIndicator };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/OnBalanceVolumeIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { OnBalanceVolumeIndicatorStrategy } from "./OnBalanceVolumeIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var OnBalanceVolumeIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(OnBalanceVolumeIndicator, _super);
    function OnBalanceVolumeIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OnBalanceVolumeIndicator.prototype.bj = function () {
        return new OnBalanceVolumeIndicator();
    };
    OnBalanceVolumeIndicator.prototype.get_abq = function () {
        return new OnBalanceVolumeIndicatorStrategy();
    };
    Object.defineProperty(OnBalanceVolumeIndicator.prototype, "abq", {
        get: function () {
            return this.get_abq();
        },
        enumerable: false,
        configurable: true
    });
    OnBalanceVolumeIndicator.prototype.get_ab3 = function () {
        return OnBalanceVolumeIndicator.$;
    };
    Object.defineProperty(OnBalanceVolumeIndicator.prototype, "ab3", {
        get: function () {
            return this.get_ab3();
        },
        enumerable: false,
        configurable: true
    });
    OnBalanceVolumeIndicator.$t = markType(OnBalanceVolumeIndicator, 'OnBalanceVolumeIndicator', StrategyBasedIndicator.$);
    return OnBalanceVolumeIndicator;
}(StrategyBasedIndicator));
export { OnBalanceVolumeIndicator };
